@@ -14,21 +14,23 @@
 #include "doubleprop.h"
 #include "boolprop.h"
 
-Component* Mosfet::construct( QObject* parent, QString type, QString id )
-{ return new Mosfet( parent, type, id ); }
+#define tr(str) simulideTr("Mosfet",str)
+
+Component* Mosfet::construct( QString type, QString id )
+{ return new Mosfet( type, id ); }
 
 LibraryItem* Mosfet::libraryItem()
 {
     return new LibraryItem(
-        QCoreApplication::translate("Mosfet", "Mosfet"),
+        tr("Mosfet"),
         "Transistors",
         "mosfet.png",
         "Mosfet",
         Mosfet::construct);
 }
 
-Mosfet::Mosfet( QObject* parent, QString type, QString id )
-      : Component( parent, type, id )
+Mosfet::Mosfet( QString type, QString id )
+      : Component( type, id )
       , eMosfet( id )
 {
     m_area = QRectF(-12, -14, 28, 28 );
@@ -42,12 +44,19 @@ Mosfet::Mosfet( QObject* parent, QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new BoolProp<Mosfet>("P_Channel", tr("P Channel"),"", this, &Mosfet::pChannel,  &Mosfet::setPchannel ),
-new BoolProp<Mosfet>("Depletion", tr("Depletion"),"", this, &Mosfet::depletion, &Mosfet::setDepletion ),
+new BoolProp<Mosfet>("P_Channel", tr("P Channel"),""
+                        , this, &Mosfet::pChannel, &Mosfet::setPchannel ),
+
+new BoolProp<Mosfet>("Depletion", tr("Depletion"),""
+                    , this, &Mosfet::depletion, &Mosfet::setDepletion ),
     },0} );
+
     addPropGroup( { tr("Electric"), {
-new DoubProp<Mosfet>("RDSon"    , tr("RDSon")    ,"Ω", this, &Mosfet::rdson,     &Mosfet::setRDSon),
-new DoubProp<Mosfet>("Threshold", tr("Threshold"),"V", this, &Mosfet::threshold, &Mosfet::setThreshold )
+new DoubProp<Mosfet>("RDSon"    , tr("RDSon"),"Ω"
+                    , this, &Mosfet::rdson, &Mosfet::setRDSon),
+
+new DoubProp<Mosfet>("Threshold", tr("Threshold"),"V"
+                    , this, &Mosfet::threshold, &Mosfet::setThreshold )
     },0} );
 }
 Mosfet::~Mosfet(){}
@@ -59,12 +68,26 @@ void Mosfet::updateStep()
     if( !m_changed ) return;
     m_changed = false;
 
+    updateValues();
     voltChanged();
 }
 
-void Mosfet::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
+void Mosfet::setPchannel( bool p )
 {
-    Component::paint( p, option, widget );
+    m_Pchannel = p;
+    m_changed = true;
+    update();
+}
+void Mosfet::setDepletion( bool d )
+{
+    m_depletion = d;
+    m_changed = true;
+    update();
+}
+
+void Mosfet::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w )
+{
+    Component::paint( p, o, w);
     
     if( Circuit::self()->animate() && m_gateV > 0 )  p->setBrush( Qt::yellow );
     else                                             p->setBrush( Qt::white );
@@ -105,4 +128,6 @@ void Mosfet::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget
         p->drawLine( 0,-9, 0,-5 );
         p->drawLine( 0,-2, 0, 2 );
         p->drawLine( 0, 5, 0, 9 );
-}   }
+    }
+    Component::paintSelected( p );
+}
