@@ -5,7 +5,6 @@
 
 #include <QMenu>
 #include <QFileDialog>
-#include <QPushButton>
 #include <QInputDialog>
 #include <QGraphicsProxyWidget>
 
@@ -17,6 +16,7 @@
 #include "itemlibrary.h"
 #include "utils.h"
 #include "iopin.h"
+#include "custombutton.h"
 
 #include "stringprop.h"
 #include "boolprop.h"
@@ -79,14 +79,25 @@ Function::Function( QString type, QString id )
     setFunctions( "i0 | i1" );
 
     addPropGroup( { tr("Main"), {
-new IntProp<Function>("Num_Inputs" , tr("Input Size") ,"_Pins", this, &Function::numInps,   &Function::setNumInputs ,0,"uint" ),
-new IntProp<Function>("Num_Outputs", tr("Output Size"),"_Pins", this, &Function::numOuts,   &Function::setNumOutputs,0,"uint" ),
-new StrProp<Function>("Functions"  , tr("Functions")  ,""     , this, &Function::functions, &Function::setFunctions ),
-    },groupNoCopy} );
+new IntProp<Function>("Num_Inputs" , tr("Input Size") ,"_Pins"
+                     , this, &Function::numInps, &Function::setNumInputs, propNoCopy ,"uint" ),
+
+new IntProp<Function>("Num_Outputs", tr("Output Size"),"_Pins"
+                     , this, &Function::numOuts, &Function::setNumOutputs, propNoCopy ,"uint" ),
+
+new StrProp<Function>("Functions", tr("Functions"),""
+                     , this, &Function::functions, &Function::setFunctions ),
+    }, groupNoCopy } );
+
     addPropGroup( { tr("Electric"), IoComponent::inputProps()
-+QList<ComProperty*>({new BoolProp<Function>( "Invert_Inputs", tr("Invert Inputs"),"", this, &Function::invertInps, &Function::setInvertInps, propNoCopy )})
-                    +IoComponent::outputProps()+IoComponent::outputType(),0 } );
-    addPropGroup( { tr("Edges"), IoComponent::edgeProps(),0 } );
++QList<ComProperty*>({
+new BoolProp<Function>( "Invert_Inputs", tr("Invert Inputs"),""
+                      , this, &Function::invertInps, &Function::setInvertInps, propNoCopy )})
+
+                    + IoComponent::outputProps()
+                    + IoComponent::outputType(),0 } );
+
+    addPropGroup( { tr("Timing"), IoComponent::edgeProps(),0 } );
 }
 Function::~Function(){}
 
@@ -260,11 +271,11 @@ void Function::saveData()
 
 void Function::remove()
 {
-    for( QPushButton* button : m_buttons ) 
+    for( CustomButton* button : m_buttons )
     {
-       m_buttons.removeOne( button );
        delete button;
     }
+    m_buttons.clear();
     IoComponent::remove();
 }
 
@@ -312,8 +323,8 @@ void Function::setNumOutputs( int outs )
                 m_outPin[i]->setY( -halfH+(int)i*16+8 );
                 m_proxys.at(i)->setPos( QPoint( 0, -halfH+(int)i*16+1 ) );
             }else{
-                QPushButton* button = m_buttons.takeLast();
-                //QObject::disconnect( button, &QPushButton::released, this, &Function::onbuttonclicked );
+                CustomButton* button = m_buttons.takeLast();
+                //QObject::disconnect( button, &CustomButton::released, this, &Function::onbuttonclicked );
                 delete button;
 
                 m_proxys.removeLast();
@@ -331,15 +342,17 @@ void Function::setNumOutputs( int outs )
             }else{
                 QString num = QString::number(i);
                 m_outPin[i] = new IoPin( 0, QPoint(24, -halfH+i*16+8 ), m_id+"-out"+num, i, this, output );
+                initPin( m_outPin[i] );
+                m_outPin[i]->setInverted( m_invOutputs );
 
-                QPushButton* button = new QPushButton( );
+                CustomButton* button = new CustomButton( );
                 button->setMaximumSize( 14,14 );
                 button->setGeometry(-14,-14,14,14);
                 QFont font = button->font();
                 font.setPixelSize(7);
                 button->setFont(font);
                 button->setText( "O"+num );
-                button->setCheckable( true );
+//                button->setCheckable( true );
                 m_buttons.append( button );
 
                 QGraphicsProxyWidget* proxy = Circuit::self()->addWidget( button );
@@ -349,19 +362,19 @@ void Function::setNumOutputs( int outs )
                 m_proxys.append( proxy );
                 m_funcList.append( "" );
 
-                QObject::connect( button, &QPushButton::released, [=](){ onbuttonclicked(); } );
+                QObject::connect( button, &CustomButton::released, [=](){ onbuttonclicked( i ); } );
     }   }   }
     
     Circuit::self()->update();
 }
 
-void Function::onbuttonclicked()
+void Function::onbuttonclicked( int  i )
 {
-    int i = 0;
-    for( QPushButton* button : m_buttons ){
-       if( button->isChecked()  ){ button->setChecked( false ); break; }
-       ++i;
-    }
+//    int i = 0;
+//    for( CustomButton* button : m_buttons ){
+//       if( button->isChecked()  ){ button->setChecked( false ); break; }
+//       ++i;
+//    }
     bool ok;
     QString text = QInputDialog::getText(0l, tr("Set Function"),
                                              "Output "+QString::number(i)+tr(" Function:"),
