@@ -38,6 +38,7 @@ Dht22::Dht22( QString type, QString id )
 {
     m_area = QRect(-28,-20, 56, 40 );
 
+    m_graphical = true;
     m_temp = 22.5;
     m_humi = 68.5;
     m_tempInc = 0.5;
@@ -70,12 +71,14 @@ Dht22::Dht22( QString type, QString id )
     m_button->setIcon(QIcon(":/up.png"));
 
     QPushButton* u_button = new QPushButton();
+    u_button->setCursor( Qt::PointingHandCursor );
     u_button->setMaximumSize( 9, 9 );
     u_button->setGeometry(-5,-5, 9, 9);
     u_button->setCheckable( false );
     u_button->setIcon(QIcon(":/su.png"));
 
     QPushButton* d_button = new QPushButton();
+    d_button->setCursor( Qt::PointingHandCursor );
     d_button->setMaximumSize( 9, 9 );
     d_button->setGeometry(-5,-5, 9, 9);
     d_button->setCheckable( false );
@@ -98,9 +101,14 @@ Dht22::Dht22( QString type, QString id )
     QObject::connect( d_button, &QPushButton::pressed, [=](){ downbuttonclicked(); } );
 
     addPropGroup( { tr("Main"), {
-new StrProp <Dht22>("DHT22"  , tr("Model")           ,""  , this, &Dht22::model,    &Dht22::setModel, propNoCopy,"enum"  ),
-new DoubProp<Dht22>("TempInc", tr("Temp. increment") ,"°C", this, &Dht22::tempInc,  &Dht22::setTempInc ),
-new DoubProp<Dht22>("HumiInc", tr("Humid. increment"),"_%", this, &Dht22::humidInc, &Dht22::setHumidInc ),
+new StrProp <Dht22>("DHT22", tr("Model"),""
+                   , this, &Dht22::model, &Dht22::setModel, propNoCopy,"enum"  ),
+
+new DoubProp<Dht22>("TempInc", tr("Temp. increment") ,"°C"
+                   , this, &Dht22::tempInc, &Dht22::setTempInc ),
+
+new DoubProp<Dht22>("HumiInc", tr("Humid. increment"),"_%"
+                   , this, &Dht22::humidInc, &Dht22::setHumidInc ),
     },0} );
 }
 Dht22::~Dht22(){}
@@ -275,4 +283,6 @@ void Dht22::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget*
     p->setPen( QColor(0, 0, 0) );
     p->drawText( -16, 1, QString::number( m_temp )+"°C" );
     p->drawText( -16,12, QString::number( m_humi )+" %" );
+
+    Component::paintSelected( p );
 }
