@@ -6,7 +6,6 @@
 #include <QCursor>
 #include <QPainter>
 #include <QTextDocument>
-#include <QMenu>
 #include <QGuiApplication>
 
 #include "textcomponent.h"
@@ -37,11 +36,9 @@ LibraryItem* TextComponent::libraryItem()
 }
 
 TextComponent::TextComponent( QString type, QString id )
-             : Component( type, id )
-             , Linkable()
+             : LinkerComponent( type, id )
 {
     m_graphical = true;
-    m_linkable  = true;
     m_changed   = false;
     m_opac = 1;
     m_color = QColor( 255, 255, 220 );
@@ -82,21 +79,35 @@ TextComponent::TextComponent( QString type, QString id )
     QObject::connect( m_text->document(), &QTextDocument::contentsChange, [=](int f, int cr, int ca){ updateGeometry(f,cr,ca); } );
 
     addPropGroup( { tr("Main"), {
-new IntProp <TextComponent>("Margin" , tr("Margin") ,"_Pixels"  , this, &TextComponent::margin,  &TextComponent::setMargin ),
-new IntProp <TextComponent>("Border" , tr("Border") ,"_Pixels"  , this, &TextComponent::border,  &TextComponent::setBorder,0,"uint" ),
-new StrProp <TextComponent>("Color"  , tr("Background Color"),"", this, &TextComponent::colorStr,&TextComponent::setColorStr ),
-new DoubProp<TextComponent>("Opacity", tr("Opacity")         ,"", this, &TextComponent::opac,    &TextComponent::setOpac )
+new IntProp <TextComponent>("Margin", tr("Margin"),"_px"
+                           , this, &TextComponent::margin, &TextComponent::setMargin ),
+
+new IntProp <TextComponent>("Border", tr("Border"),"_px"
+                           , this, &TextComponent::border, &TextComponent::setBorder,0,"uint" ),
+
+new StrProp <TextComponent>("Color", tr("Background Color"),""
+                           , this, &TextComponent::colorStr,&TextComponent::setColorStr ),
+
+new DoubProp<TextComponent>("Opacity", tr("Opacity"),""
+                           , this, &TextComponent::opac, &TextComponent::setOpac )
     }, groupNoCopy} );
+
     addPropGroup( { tr("Text"), {
-new StrProp <TextComponent>("Font"       , tr("Font")      ,""       , this, &TextComponent::getFont  , &TextComponent::setFont ),
-new IntProp <TextComponent>("Font_Size"  , tr("Font Size") ,"_Pixels", this, &TextComponent::fontSize , &TextComponent::setFontSize ),
-new StrProp <TextComponent>("Font_Color" , tr("Font Color"),""       , this, &TextComponent::fontColor, &TextComponent::setFontColor ),
-new BoolProp<TextComponent>("Fixed_Width", tr("Fixed_Width"),""      , this, &TextComponent::fixedW   , &TextComponent::setFixedW ),
-new StrProp <TextComponent>("Text"       , tr("Text")        ,""     , this, &TextComponent::getText  , &TextComponent::setText,0,"textEdit" )
+new StrProp <TextComponent>("Font", tr("Font"),""
+                           , this, &TextComponent::getFont , &TextComponent::setFont ),
+
+new StrProp <TextComponent>("Font_Color", tr("Font Color"),""
+                           , this, &TextComponent::fontColor, &TextComponent::setFontColor,0,"color" ),
+
+new IntProp <TextComponent>("Font_Size", tr("Font Size") ,"_px"
+                           , this, &TextComponent::fontSize , &TextComponent::setFontSize ),
+
+new BoolProp<TextComponent>("Fixed_Width", tr("Fixed_Width"),""
+                           , this, &TextComponent::fixedW, &TextComponent::setFixedW ),
+
+new StrProp <TextComponent>("Text", tr("Text"),""
+                           , this, &TextComponent::getText, &TextComponent::setText,0,"textEdit" )
     }, groupNoCopy} );
-    addPropGroup( { "Hidden", {
-new StrProp<TextComponent>( "Links", "Links","", this, &TextComponent::getLinks , &TextComponent::setLinks )
-    }, groupHidden | groupNoCopy} );
 }
 TextComponent::~TextComponent()
 {
@@ -213,14 +224,14 @@ void TextComponent::setText( QString text )
 void TextComponent::createLinks( QList<Component*>* compList )
 {
     m_changed = true;
-    Linkable::createLinks( compList );
+    Linker::createLinks( compList );
     if( !Simulator::self()->isRunning() ) updateStep();
 }
 
 void TextComponent::compSelected( Component* comp )
 {
     m_changed = true;
-    Linkable::compSelected( comp );
+    Linker::compSelected( comp );
     if( !Simulator::self()->isRunning() ) updateStep();
 }
 
@@ -238,22 +249,6 @@ void TextComponent::setLinkedValue( double v, int i )
     else         setText( m_textString+"/n"+str );
 }
 
-void TextComponent::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
-{
-    if( !acceptedMouseButtons() ) { event->ignore(); return; }
-
-    event->accept();
-    QMenu* menu = new QMenu();
-
-    QAction* linkCompAction = menu->addAction( QIcon(":/subcl.png"),tr("Link to Component") );
-    QObject::connect( linkCompAction, &QAction::triggered, [=](){ slotLinkComp(); } );
-
-    menu->addSeparator();
-
-    Component::contextMenu( event, menu );
-    menu->deleteLater();
-}
-
 void TextComponent::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
 {
     Component::paint( p, option, widget );
@@ -271,4 +266,5 @@ void TextComponent::paint( QPainter* p, const QStyleOptionGraphicsItem* option,
         p->setBrush( Qt::transparent );
         p->drawRect( m_area );
     }
+    Component::paintSelected( p );
 }
