@@ -8,11 +8,13 @@
 #include "ssd1306.h"
 #include "itemlibrary.h"
 #include "simulator.h"
+#include "circuitview.h"
 #include "circuit.h"
 #include "iopin.h"
 
 #include "doubleprop.h"
 #include "stringprop.h"
+#include "boolprop.h"
 #include "intprop.h"
 
 #define tr(str) simulideTr("Ssd1306",str)
@@ -41,7 +43,7 @@ Ssd1306::Ssd1306( QString type, QString id )
     m_width = 128;
     m_height = 64;
     m_rows   = 8;
-    m_area = QRectF( -70, -m_height/2-16, m_width+12, m_height+24 );
+    m_area = QRectF(-70,-m_height/2-16, m_width+12, m_height+24 );
     m_address = m_cCode = 0b00111100; // 0x3A - 60
 
     m_enumUids = QStringList()
@@ -69,10 +71,8 @@ Ssd1306::Ssd1306( QString type, QString id )
     //m_pinDC.setLabelText(  "DC" );
     //m_pinCS.setLabelText(  "CS" );
 
-    m_pdisplayImg = new QImage( 128, 64, QImage::Format_MonoLSB );
-    m_pdisplayImg->setColor( 0, qRgb(0, 0, 0));
-    m_pdisplayImg->setColor( 1, qRgb(255, 255, 255) );
     m_dColor = White;
+    m_rotate = true;
     
     Simulator::self()->addToUpdateList( this );
     
@@ -81,12 +81,27 @@ Ssd1306::Ssd1306( QString type, QString id )
     
     Ssd1306::initialize();
 
+
     addPropGroup( { tr("Main"), {
-new StrProp <Ssd1306>("Color"       ,tr("Color")        ,""           ,this,&Ssd1306::colorStr,&Ssd1306::setColorStr,0,"enum" ),
-new IntProp <Ssd1306>("Width"       ,tr("Width")        ,tr("_Pixels"),this,&Ssd1306::width,   &Ssd1306::setWidth, propNoCopy,"uint" ),
-new IntProp <Ssd1306>("Height"      ,tr("Height")       ,tr("_Pixels"),this,&Ssd1306::height,  &Ssd1306::setHeight, propNoCopy,"uint" ),
-new IntProp <Ssd1306>("Control_Code",tr("I2C Address")  ,""           ,this,&Ssd1306::cCode,   &Ssd1306::setCcode,0,"uint" ),
-new DoubProp<Ssd1306>("Frequency"   ,tr("I2C Frequency"),"_KHz"       ,this,&Ssd1306::freqKHz, &Ssd1306::setFreqKHz ),
+new StrProp <Ssd1306>("Color" ,tr("Color"), ""
+                     ,this, &Ssd1306::colorStr, &Ssd1306::setColorStr,0,"enum" ),
+
+new IntProp <Ssd1306>("Width", tr("Width"), tr("_Px")
+                     , this, &Ssd1306::width, &Ssd1306::setWidth, propNoCopy,"uint" ),
+
+new IntProp <Ssd1306>("Height", tr("Height"), tr("_Px")
+                        ,this,&Ssd1306::height, &Ssd1306::setHeight, propNoCopy,"uint" ),
+
+new BoolProp<Ssd1306>("Rotate", tr("Rotate"), ""
+                     , this, &Ssd1306::imgRotated, &Ssd1306::setImgRotated ),
+    }, 0} );
+
+    addPropGroup( { tr("I2C"), {
+new IntProp <Ssd1306>("Control_Code", tr("I2C Address"), ""
+                     , this, &Ssd1306::cCode, &Ssd1306::setCcode,0,"uint" ),
+
+new DoubProp<Ssd1306>("Frequency",tr("I2C Frequency"), "_KHz"
+                     , this, &Ssd1306::freqKHz, &Ssd1306::setFreqKHz ),
     }, 0} );
 }
 Ssd1306::~Ssd1306(){}
@@ -96,8 +111,8 @@ void Ssd1306::initialize()
     TwiModule::initialize();
 
     m_continue = false;
-    m_command = false;
-    m_data = false;
+    m_command  = false;
+    m_data     = false;
     m_addrMode = HORI_ADDR_MODE;
 
     clearDDRAM();
@@ -110,63 +125,19 @@ void Ssd1306::stamp()
     setMode( TWI_SLAVE );
 }
 
-void Ssd1306::updateStep()
-{
-    if     ( !m_dispOn )  m_pdisplayImg->fill(0);  // Display Off
-    else if( m_dispFull ) m_pdisplayImg->fill(255); // Display fully On
-    else{
-        if( m_scroll )
-        {
-            m_scrollCount--;
-            if( m_scrollCount <= 0 )
-            {
-                m_scrollCount = m_scrollInterval;
-
-                for( int row=m_scrollStartPage; row<=m_scrollEndPage; row++ )
-                {
-                    unsigned char start = m_aDispRam[0][row];
-                    unsigned char end   = m_aDispRam[127][row];
-
-                    for( int col=0; col<128; col++ )
-                    {
-                        if( m_scrollR )
-                        {
-                            int c = 127-col;
-                            if( c < 127 ) m_aDispRam[c][row] = m_aDispRam[c-1][row];
-                            if( col == 0 )  m_aDispRam[0][row]   = end;
-                        }else{
-                            if( col < 127 )  m_aDispRam[col][row] = m_aDispRam[col+1][row];
-                            if( col == 127 ) m_aDispRam[col][row] = start;
-        }   }   }   }   }
-        for( int row=0; row<8; row++ )
-        {
-            for( int col=0; col<128; col++ )
-            {
-                unsigned char abyte = m_aDispRam[col][row];
-
-                if( m_dispInv ) abyte = ~abyte;         // Display Inverted
-
-                for( int bit=0; bit<8; bit++ )
-                {
-                    m_pdisplayImg->setPixel(col,row*8+bit,(abyte & 1) );
-                    abyte >>= 1;
-    }   }   }   }
-    update();
-}
-
 void Ssd1306::reset()
 {
-    m_cdr = 1;
-    m_mr  = 63;
+    m_cdr  = 1;
+    m_mr   = 63;
     m_fosc = 370000;
-    m_frm = m_fosc/(m_cdr*54*m_mr);
+    m_frm  = m_fosc/(m_cdr*54*m_mr);
 
     m_addrX  = 0;
     m_addrY  = 0;
     m_startX = 0;
     m_endX   = 127;
     m_startY = 0;
-    m_endY   = m_rows-1;
+    m_endY   = 7; //m_rows-1;
 
     m_scrollStartPage  = 0;
     m_scrollEndPage    = 7;
@@ -179,12 +150,38 @@ void Ssd1306::reset()
     m_dispOn   = false;
     m_dispFull = false;
     m_dispInv  = false;
+    m_scanInv  = false;
+    m_scroll   = false;
+    m_scrollR  = false;
+    m_scrollV  = false;
+}
 
-    m_scroll  = false;
-    m_scrollR = false;
-    m_scrollV = false;
+void Ssd1306::updateStep()
+{
+    if( m_scroll )
+    {
+        m_scrollCount--;
+        if( m_scrollCount <= 0 )
+        {
+            m_scrollCount = m_scrollInterval;
 
-    clearLcd();
+            for( int row=m_scrollStartPage; row<=m_scrollEndPage; row++ )
+            {
+                unsigned char start = m_aDispRam[0][row];
+                unsigned char end   = m_aDispRam[127][row];
+
+                for( int col=0; col<128; col++ )
+                {
+                    if( m_scrollR ){
+                        int c = 127-col;
+                        if( c < 127  ) m_aDispRam[c][row] = m_aDispRam[c-1][row];
+                        if( col == 0 ) m_aDispRam[0][row] = end;
+                    }else{
+                        if( col < 127  ) m_aDispRam[col][row] = m_aDispRam[col+1][row];
+                        if( col == 127 ) m_aDispRam[col][row] = start;
+    }   }   }   }   }
+
+    update();
 }
 
 void Ssd1306::I2Cstop()
@@ -243,7 +240,7 @@ void Ssd1306::proccessCommand()
             if( m_readBytes == 2 ) m_startY = m_rxReg & 0x07; // 0b00000111
             else{                                             // 0b00000111
                 m_endY = m_rxReg & 0x07;
-                if( m_endY > m_rows-1 ) m_endY = m_rows-1;
+                //if( m_endY > m_rows-1 ) m_endY = m_rows-1;
             }
         }
         else if( m_lastCommand == 0x26   // 26 36 Continuous Horizontal Scroll Setup
@@ -293,6 +290,11 @@ void Ssd1306::proccessCommand()
         {
             ; /// TODO
         }
+        else if( m_lastCommand == 0xA8 ) // A8 168 Set Multiplex Ratio
+        {
+            uint8_t muxRatio  = m_rxReg & 0x3F;  // 0b00111111
+            if( muxRatio > 14 ) m_mr = muxRatio;
+        }
         m_readBytes--;
         return;
     }
@@ -337,8 +339,8 @@ void Ssd1306::proccessCommand()
     else if( m_rxReg == 0xA3 ) m_readBytes = 2;     // A3 163 Set Vertical Scroll Area
     else if( m_rxReg == 0xA4 ) m_dispFull = false;  // A4-A5 164-165 Entire Display ON
     else if( m_rxReg == 0xA5 ) m_dispFull = true;
-    else if( m_rxReg == 0xA6 ) m_dispInv = false;   // A6-A7 166-167 Set Normal/inverse Display
-    else if( m_rxReg == 0xA7 ) m_dispInv = true;
+    else if( m_rxReg == 0xA6 ) m_dispInv  = false;  // A6-A7 166-167 Set Normal/inverse Display
+    else if( m_rxReg == 0xA7 ) m_dispInv  = true;
     else if( m_rxReg == 0xA8 ) m_readBytes = 1;     // A8 168 Set Multiplex Ratio
 
     else if( m_rxReg == 0xAE ) reset();             // 174 // AE-AF Set Display ON/OFF
@@ -349,6 +351,8 @@ void Ssd1306::proccessCommand()
         m_addrY = m_rxReg & 0x07; // 0b00000111
     }
     // C0-C8 192-200 Set COM Output Scan Direction
+    else if( m_lastCommand == 0xC0 ) m_scanInv = false;
+    else if( m_lastCommand == 0xC8 ) m_scanInv = true;
 
     else if( m_rxReg == 0xD3 ) m_readBytes = 1; // D3 211 Set Display Offset
 
@@ -359,11 +363,6 @@ void Ssd1306::proccessCommand()
     else if( m_rxReg == 0xDB ) m_readBytes = 1; // DB 219 SET VCOM DETECT
 }
 
-void Ssd1306::clearLcd() 
-{
-    m_pdisplayImg->fill(0);
-}
-
 void Ssd1306::clearDDRAM() 
 {
     for( int row=0; row<8; row++ )
@@ -394,20 +393,14 @@ void Ssd1306::incrementPointer()
             if( m_addrY > m_endY ) m_addrY = m_startY;
 }   }   }
 
-void Ssd1306::remove()
-{
-    delete m_pdisplayImg;
-    Component::remove();
-}
-
 void Ssd1306::setColorStr( QString color )
 {
     int c = getEnumIndex(  color );
     m_dColor = (dispColor)c;
 
-    if( c == White )  m_pdisplayImg->setColor( 1, qRgb(245, 245, 245) );
-    if( c == Blue  )  m_pdisplayImg->setColor( 1, qRgb(200, 200, 255) );
-    if( c == Yellow ) m_pdisplayImg->setColor( 1, qRgb(245, 245, 100) );
+    if( c == White )  m_foreground = QColor(245, 245, 245);
+    if( c == Blue  )  m_foreground = QColor(200, 200, 255);
+    if( c == Yellow ) m_foreground = QColor(245, 245, 100);
 
     if( m_showVal && (m_showProperty == "Color") )
         setValLabelText( m_enumNames.at( c ) );
@@ -441,12 +434,47 @@ void Ssd1306::updateSize()
     Circuit::self()->update();
 }
 
-void Ssd1306::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
+void Ssd1306::paint( QPainter* p, const QStyleOptionGraphicsItem*, QWidget* )
 {
     QPen pen( Qt::black, 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin );
     p->setPen( pen );
     
     p->setBrush( QColor( 50, 70, 100 ) );
     p->drawRoundedRect( m_area, 2, 2 );
-    p->drawImage(-64,-m_height/2-10, *m_pdisplayImg, 0, 0, m_width, m_height );
+
+    if( m_dispFull ) p->fillRect(-64,-m_height/2-10, m_width, m_height, m_foreground );
+    else{
+        QImage img( m_width*3, m_height*3, QImage::Format_RGB32 );
+        QPainter painter;
+        painter.begin( &img );
+        painter.fillRect( 0, 0, m_width*3, m_height*3, Qt::black );
+
+        bool scanInv = m_rotate ? !m_scanInv : m_scanInv;
+
+        if( m_dispOn  ){
+            for( int row=0; row<8; row++ ){
+                for( int col=0; col<128; col++ )
+                {
+                    uint8_t abyte = m_aDispRam[col][row];
+                    if( m_dispInv ) abyte = ~abyte;      // Display Inverted
+
+                    int x = col*3;
+                    if( scanInv ) x = 127*3-x;
+
+                    for( int bit=0; bit<8; bit++ )
+                    {
+                        if( abyte & 1 ){
+                            int y = row*8+bit;
+                            if( y >= m_height ) continue;
+                            if( y > m_mr ) continue;
+                            if( scanInv ) y = 63-y;
+                            painter.fillRect( x, y*3, 3, 3, m_foreground );
+                       }
+                        abyte >>= 1;
+        }   }   }   }
+
+        painter.end();
+        p->drawImage(QRectF(-64,-m_height/2-10, m_width, m_height), img );
+    }
+    Component::paintSelected( p );
 }
