@@ -9,16 +9,29 @@
 #include "component.h"
 #include "comproperty.h"
 #include "propdialog.h"
+//#include "mainwindow.h"
 
-ColorVal::ColorVal( PropDialog* parent, Component* comp, ComProperty* prop )
+ColorVal::ColorVal( PropDialog* parent, CompBase* comp, ComProperty* prop )
         : PropVal( parent, comp, prop )
 {
     setupUi(this);
+    m_blocked = true;
 }
 ColorVal::~ColorVal(){}
 
-void ColorVal::setup()
+void ColorVal::setup( bool )
 {
+    //float scale = MainWindow::self()->fontScale();
+    //QFont font = valLabel->font();
+    //font.setPixelSize( 11.0*scale );
+    //valLabel->setFont( font );
+    //colorW->setFont( font );
+    //valueBox->setFont( font );
+
+    QFontMetrics fm( valueBox->font() );
+    float scale = fm.width(" ")/2;
+    valueBox->setFixedWidth( 170.0*scale );
+
     valLabel->setText( m_property->capt() );
 
     m_color = m_property->getValStr(); /// FIXME // comp->property( m_propName.toUtf8() ).value<QColor>();
@@ -43,10 +56,13 @@ void ColorVal::setup()
     colorW->setPalette( pal );
 
     this->adjustSize();
+
+    m_blocked = false;
 }
 
-void ColorVal::on_valueBox_currentIndexChanged( int index )
+void ColorVal::on_valueBox_activated( int index )
 {
+    if( m_blocked ) return;
     if( !m_component ) return;
 
     QString value = valueBox->itemText( index );
