@@ -6,8 +6,9 @@
 #include "numval.h"
 #include "component.h"
 #include "propdialog.h"
-#include "utils.h"
 #include "comproperty.h"
+#include "mainwindow.h"
+#include "utils.h"
 
 NumVal::NumVal( PropDialog* parent, CompBase* comp, ComProperty* prop )
       : PropVal( parent, comp, prop )
@@ -27,14 +28,34 @@ void NumVal::setup( bool isComp )
 
     if( !isComp ) showVal->setVisible( false );
 
+    //QFont font = valueBox->font();
+    QFontMetrics fm( valLabel->font() );
+    float scale = fm.width(" ")/2;
+    //font.setPixelSize( 11.0*scale );
+    //unitBox->setFont( font );
+    //valueBox->setFont( font );
+    //valLabel->setFont( font );
+
+    //float scale = MainWindow::self()->fontScale();
+    unitBox->setFixedWidth( 65.0*scale );
+    unitSpace->setFixedWidth( 65.0*scale );
+    valueBox->setFixedWidth( 100.0*scale );
+
+    unitSpace->setVisible( false );
     QString unit = m_property->unit();
 
+    //unitBox->setStyleSheet( "QComboBox::drop-down { width: 5px; min-width: 5px; max-width: 5px; icon-size: 1px}");
+
     if( unit.isEmpty() || unit.startsWith("_") )
     {
         m_useMult = false;
-        unitBox->setStyleSheet( "QComboBox::drop-down {border-width: 0px;} \
-                                 QComboBox::down-arrow {image: url(noimg); border-width: 0px;}");
-        if( unit.startsWith("_") ) unitBox->addItem( unit.remove("_") ); // No multiplier
+
+        if( unit.isEmpty() )
+        {
+            unitBox->setVisible( false );
+            unitSpace->setVisible( true );
+        }
+        else if( unit.startsWith("_") ) unitBox->addItem( unit.remove("_") ); // No multiplier
     }else{
         m_useMult = true;
         QString un = unit;
@@ -48,7 +69,6 @@ void NumVal::setup( bool isComp )
     }
     m_blocked = false;
     updtValues();
-    ///this->adjustSize();
 }
 
 void NumVal::on_showVal_toggled( bool checked )
@@ -60,7 +80,7 @@ void NumVal::on_showVal_toggled( bool checked )
         m_component->setPropStr("ShowProp", m_propName );
         m_component->setPropStr("ValLabelText", getValWithUnit() );
     }
-    else m_component->setPropStr("ShowProp", "" );  //setShowProp( "" );
+    else m_component->setPropStr("ShowProp", "" );
     m_propDialog->updtValues();
     m_propDialog->changed();
     m_blocked = false;
@@ -71,11 +91,12 @@ void NumVal::on_valueBox_valueChanged( double val )
     if( m_blocked ) return;
     m_blocked = true;
 
+    prepareChange();
     if( m_useMult ) m_property->setValStr( getValWithUnit() );
     else            m_property->setValStr( QString::number( valueBox->value() ) );
     m_blocked = false;
     m_propDialog->updtValues();
-    m_propDialog->changed();
+    saveChanges();
 }
 
 void NumVal::on_unitBox_currentTextChanged( QString unit )
@@ -103,11 +124,6 @@ void NumVal::updtValues()
 
     if( showVal->isChecked() ) m_component->setPropStr("ValLabelText", m_property->getValStr() );
 
-    /*QString valStr = m_property->getValStr();
-    QStringList l = valStr.split(" ");
-    valueBox->setValue( l.first().toDouble() );
-    unitBox->setCurrentText( l.last() );*/
-
     m_blocked = false;
 }
 
