@@ -11,15 +11,17 @@
 
 #include "doubleprop.h"
 
-ModuleSubc::ModuleSubc( QObject* parent, QString type, QString id )
-          : ShieldSubc( parent, type, id )
+#define tr(str) simulideTr("ModuleSubc",str)
+
+ModuleSubc::ModuleSubc( QString type, QString id )
+          : ShieldSubc( type, id )
 {
     m_subcType = Chip::Module;
     setZValue( 2 );
 
     addPropGroup( { tr("Main"), {
 new DoubProp<ModuleSubc>( "Z_Value", tr("Z Value"),"", this, &ModuleSubc::zVal, &ModuleSubc::setZVal )
-    }} );
+    },0} );
 }
 ModuleSubc::~ModuleSubc(){}
 
@@ -32,7 +34,15 @@ void ModuleSubc::setZVal( double v )
 
 void ModuleSubc::attachToBoard()
 {
-    m_boardPos = m_circPos - m_board->pos();
+    BoardSubc* board = m_board;
+    if( board->subcType() > Board )
+    {
+        ShieldSubc* shield = static_cast<ShieldSubc*>(board);
+        BoardSubc* parentBoard = shield->parentBoard();
+        if( parentBoard ) board = parentBoard;
+    }
+    m_boardPos = m_circPos - board->pos();
+    if( board != m_board ) m_boardPos -= m_board->pos();
 }
 
 void ModuleSubc::renameTunnels()
