@@ -8,7 +8,7 @@
 
 #include "board.h"
 
-class MAINMODULE_EXPORT ShieldSubc : public BoardSubc
+class ShieldSubc : public BoardSubc
 {
     public:
         ShieldSubc( QString type, QString id );
@@ -16,12 +16,15 @@ class MAINMODULE_EXPORT ShieldSubc : public BoardSubc
 
         QString boardId() { return m_boardId; }
         void setBoardId( QString id ) { m_boardId = id; }
+
         void setBoard( BoardSubc* board );
+        BoardSubc* parentBoard() { return m_board; }
 
         void connectBoard();
 
         virtual void remove() override;
 
+        virtual void contextMenuEvent( QGraphicsSceneContextMenuEvent* event ) override;
         virtual void contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu ) override;
 
     public slots:
